@@ -88,7 +88,7 @@ static word8 **enc_sd_register;
 static word8 **keyword_given=NULL;
 static int *algorithm_given=NULL;
 
-int get_block_size(int algorithm)
+int mcrypt_get_block_size(int algorithm)
 {
   switch(algorithm) {
   
@@ -667,7 +667,7 @@ pthread_mutex_lock(&counter_cur_thread);
 
 int mcrypt_ecb(int td, void *plaintext, int len)
 {
-int j,blocksize=get_block_size(algorithm_given[td]);
+int j,blocksize=mcrypt_get_block_size(algorithm_given[td]);
 char *plain=plaintext;
 
  for (j=0; j<len/blocksize; j++) {
@@ -682,7 +682,7 @@ char *plain=plaintext;
 
 int mdecrypt_ecb(int td, void *ciphertext, int len)
 {
-int j, blocksize=get_block_size(algorithm_given[td]);
+int j, blocksize=mcrypt_get_block_size(algorithm_given[td]);
 char *cipher=ciphertext;
 
  for (j=0; j<len/blocksize; j++) {
@@ -749,9 +749,9 @@ else {
 
 
 /* For cbc */
-  previous_ciphertext[cur_thread]=mxcalloc(1,get_block_size(algorithm));
-  previous_cipher[cur_thread]=mxmalloc(get_block_size(algorithm));
-  previous_plaintext[cur_thread]=mxcalloc(1,get_block_size(algorithm));
+  previous_ciphertext[cur_thread]=mxcalloc(1,mcrypt_get_block_size(algorithm));
+  previous_cipher[cur_thread]=mxmalloc(mcrypt_get_block_size(algorithm));
+  previous_plaintext[cur_thread]=mxcalloc(1,mcrypt_get_block_size(algorithm));
 
 /* End cbc */
 
@@ -777,7 +777,7 @@ int mcrypt_cbc(int td, void *plaintext, int len)
 {
   word32* fplain=plaintext;
   word32* plain;
-  int i,j, blocksize=get_block_size(algorithm_given[td]);
+  int i,j, blocksize=mcrypt_get_block_size(algorithm_given[td]);
 
  for (j=0; j<len/blocksize; j++) {
 
@@ -803,7 +803,7 @@ int mdecrypt_cbc(int td, void *ciphertext, int len)
 {
   word32* cipher;
   word32 *fcipher=ciphertext;
-  int i,j, blocksize=get_block_size(algorithm_given[td]);
+  int i,j, blocksize=mcrypt_get_block_size(algorithm_given[td]);
 
  for (j=0; j<len/blocksize; j++) {
 
@@ -879,12 +879,12 @@ else {
 
 
 /* For cfb */
-  s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  enc_s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  enc_sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  memmove(sd_register[cur_thread], IV, get_block_size(algorithm));
-  memmove(s_register[cur_thread], IV, get_block_size(algorithm));  
+  s_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  sd_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  enc_s_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  enc_sd_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  memmove(sd_register[cur_thread], IV, mcrypt_get_block_size(algorithm));
+  memmove(s_register[cur_thread], IV, mcrypt_get_block_size(algorithm));  
 
 /* End cfb */
 
@@ -908,7 +908,7 @@ x=init_mcrypt( algorithm, cur_thread, key, lenofkey);
 int mcrypt_cfb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
 {
   char* plain=plaintext;
-  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+  int i,j,blocksize=mcrypt_get_block_size(algorithm_given[td]);;
 
  for (j=0;j<len;j++) {
   
@@ -935,7 +935,7 @@ int mcrypt_cfb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb
 int mdecrypt_cfb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
 {
   char* plain=plaintext;
-  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+  int i,j,blocksize=mcrypt_get_block_size(algorithm_given[td]);;
   
  for (j=0;j<len;j++) {
  
@@ -1011,12 +1011,12 @@ else {
 
 
 /* For cfb */
-  s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  enc_s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  enc_sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
-  memmove(sd_register[cur_thread], IV, get_block_size(algorithm));
-  memmove(s_register[cur_thread], IV, get_block_size(algorithm));  
+  s_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  sd_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  enc_s_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  enc_sd_register[cur_thread]=mxmalloc( mcrypt_get_block_size(algorithm));
+  memmove(sd_register[cur_thread], IV, mcrypt_get_block_size(algorithm));
+  memmove(s_register[cur_thread], IV, mcrypt_get_block_size(algorithm));  
 
 /* End cfb */
 
@@ -1040,7 +1040,7 @@ x=init_mcrypt( algorithm, cur_thread, key, lenofkey);
 int mcrypt_ofb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
 {
   char* plain=plaintext;
-  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+  int i,j,blocksize=mcrypt_get_block_size(algorithm_given[td]);;
 
  for (j=0;j<len;j++) {
   
@@ -1067,7 +1067,7 @@ int mcrypt_ofb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb
 int mdecrypt_ofb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit cfb) */
 {
   char* plain=plaintext;
-  int i,j,blocksize=get_block_size(algorithm_given[td]);;
+  int i,j,blocksize=mcrypt_get_block_size(algorithm_given[td]);;
   
  for (j=0;j<len;j++) {
  
@@ -1239,28 +1239,25 @@ int is_ok_mode(int mode) { /* if this mode exists returns 0 */
 } 
 
 
-void gen_key(void *keyword, void *salt, size_t salt_size, size_t given_size,
+void gen_key(void *keyword, void *salt, size_t salt_size, size_t key_size,
              unsigned char *password)
 {
         unsigned char   key[MAX_KEY_LEN];
         SHA1_CTX        ctx;
         unsigned char   *digest;  
         int             plen    = strlen((void*)password);
-        size_t          size    = given_size;
+        size_t          size    = key_size;
         unsigned char   *cp     = key,
                         *cp0    = key;
-        int             salt_z  = 0;
+        int             salt_z  = 0; /* flag to be used when freeing salt[] */
         
         if (salt==NULL) { 
-          if (salt_size==0) salt_size=1;
-          salt=mxmalloc(salt_size);
-          Bzero (salt, salt_size); /* In bare mode salt is nulls */
           salt_z=1;
-        }                         /* remember? no headers there */
+        }
         
         while (1) {
                 SHA1Init(&ctx);
-                SHA1Update(&ctx, salt, salt_size);
+                if (salt_z==0) SHA1Update(&ctx, salt, salt_size);
                 SHA1Update(&ctx, password, plen);
                 if (cp - cp0 > 0)
                         SHA1Update(&ctx, cp0, cp - cp0);
@@ -1276,7 +1273,6 @@ void gen_key(void *keyword, void *salt, size_t salt_size, size_t given_size,
                         break;
                 }
         }
-        memmove (keyword, key, given_size);
-        if (salt_z==1) free(salt);
+        memmove (keyword, key, key_size);
 }
 
