@@ -1,6 +1,6 @@
 #define end_mcrypt_ecb end_mcrypt
 
-int get_block_size(int algorithm);
+int mcrypt_get_block_size(int algorithm);
 int get_key_size(int algorithm); /* returns key in bytes */
 
 int is_ok_algorithm(int algorithm); /* if this algorithm exists returns 0 */
@@ -36,7 +36,7 @@ int mcrypt_ofb(int td, void *plaintext,int len);
 int mdecrypt_ofb(int td, void *ciphertext, int len);
 int init_mcrypt_ofb( const int algorithm, void * key, int lenofkey, void *IV);
 
-void gen_key(void *keyword, void *salt, size_t salt_size, size_t given_size,
+void gen_key(void *keyword, void *salt, size_t salt_size, size_t key_size,
              unsigned char *password);
 
 # define BLOWFISH 0
